@@ -9,6 +9,8 @@ import com.unciv.logic.multiplayer.FriendList
 import com.unciv.models.UncivSound
 import com.unciv.ui.components.FontFamilyData
 import com.unciv.ui.components.Fonts
+import com.unciv.utils.Display
+import com.unciv.utils.ScreenMode
 import java.text.Collator
 import java.time.Duration
 import java.util.*
@@ -25,11 +27,6 @@ enum class ScreenSize(val virtualWidth:Float, val virtualHeight:Float){
     Huge(1500f,1000f)
 }
 
-enum class ScreenWindow {
-    Windowed,
-    Fullscreen
-}
-
 class GameSettings {
 
     var mapAutoScroll: Boolean = false
@@ -47,7 +44,7 @@ class GameSettings {
     @Deprecated("Since 4.3.6 - replaces with screenSize")
     var resolution: String = "900x600"
     var screenSize:ScreenSize = ScreenSize.Small
-    var screenWindow: ScreenWindow = ScreenWindow.Windowed
+    var screenMode: Int = 0
     var tutorialsShown = HashSet<String>()
     var tutorialTasksCompleted = HashSet<String>()
 
@@ -154,28 +151,11 @@ class GameSettings {
     fun getCollatorFromLocale(): Collator {
         return Collator.getInstance(getCurrentLocale())
     }
-
-    fun refreshScreenMode() {
-
-        if (Gdx.app.type != Application.ApplicationType.Desktop)
-            return
-
-        when (screenWindow) {
-            ScreenWindow.Windowed -> {
-                Gdx.graphics.setWindowedMode(
-                    windowState.width.coerceAtLeast(120),
-                    windowState.height.coerceAtLeast(80))
-            }
-
-            ScreenWindow.Fullscreen -> {
-                Gdx.graphics.setFullscreenMode(Gdx.graphics.displayMode)
-            }
-        }
-    }
 }
 
 enum class LocaleCode(var language: String, var country: String) {
     Arabic("ar", "IQ"),
+    Belarusian("be", "BY"),
     BrazilianPortuguese("pt", "BR"),
     Bulgarian("bg", "BG"),
     Catalan("ca", "ES"),
