@@ -21,11 +21,11 @@ import com.unciv.models.stats.Stat
 import com.unciv.models.stats.Stats
 import com.unciv.models.translations.fillPlaceholders
 import com.unciv.models.translations.tr
-import com.unciv.ui.screens.civilopediascreen.FormattedLine
 import com.unciv.ui.components.Fonts
 import com.unciv.ui.components.extensions.getConsumesAmountString
 import com.unciv.ui.components.extensions.getNeedMoreAmountString
 import com.unciv.ui.components.extensions.toPercent
+import com.unciv.ui.screens.civilopediascreen.FormattedLine
 import kotlin.math.pow
 
 
@@ -382,7 +382,7 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
                     && matchesFilter(it.params[0])
                     && city.matchesFilter(it.params[3])
                 }
-            || return super.canBePurchasedWithStat(city, stat)
+            || super.canBePurchasedWithStat(city, stat)
         )
     }
 
