@@ -41,23 +41,6 @@ object UnitActions {
         val tile = unit.getTile()
         val actionList = ArrayList<UnitAction>()
 
-        if (unit.isMoving())
-            actionList += UnitAction(UnitActionType.StopMovement) { unit.action = null }
-        if (unit.isExploring())
-            actionList += UnitAction(UnitActionType.StopExploration) { unit.action = null }
-        if (unit.isAutomated())
-            actionList += UnitAction(UnitActionType.StopAutomation) { unit.action = null }
-
-        addSleepActions(actionList, unit, false)
-        addFortifyActions(actionList, unit, false)
-
-        addPromoteAction(unit, actionList)
-        UnitActionsUpgrade.addUnitUpgradeAction(unit, actionList)
-        UnitActionsPillage.addPillageAction(unit, actionList)
-        addExplorationActions(unit, actionList)
-        addWaitAction(unit, actionList)
-        addToggleActionsAction(unit, actionList)
-
         // Determined by unit uniques
         addTransformAction(unit, actionList)
         addParadropAction(unit, actionList)
@@ -76,6 +59,26 @@ object UnitActions {
         addTriggerUniqueActions(unit, actionList)
         addAddInCapitalAction(unit, actionList, tile)
 
+        if (unit.isMoving())
+            actionList += UnitAction(UnitActionType.StopMovement) { unit.action = null }
+        if (unit.isExploring())
+            actionList += UnitAction(UnitActionType.StopExploration) { unit.action = null }
+        if (unit.isAutomated())
+            actionList += UnitAction(UnitActionType.StopAutomation) { unit.action = null }
+
+        addPromoteAction(unit, actionList)
+        UnitActionsUpgrade.addUnitUpgradeAction(unit, actionList)
+        UnitActionsPillage.addPillageAction(unit, actionList)
+        addSleepActions(actionList, unit, false)
+        addFortifyActions(actionList, unit, false)
+
+
+        if (unit.isMilitary()) addExplorationActions(unit, actionList)
+
+        addWaitAction(unit, actionList)
+
+        addToggleActionsAction(unit, actionList)
+
         return actionList
     }
 
@@ -89,6 +92,7 @@ object UnitActions {
         addSwapAction(unit, actionList)
         addDisbandAction(actionList, unit)
         addGiftAction(unit, actionList, tile)
+        if (unit.isCivilian()) addExplorationActions(unit, actionList)
 
 
         addToggleActionsAction(unit, actionList)
@@ -176,14 +180,16 @@ object UnitActions {
      * (no movement left, too close to another city).
       */
     fun getFoundCityAction(unit: MapUnit, tile: Tile): UnitAction? {
-        if (!unit.hasUnique(UniqueType.FoundCity)
-                || tile.isWater || tile.isImpassible()) return null
+        val unique = unit.getMatchingUniques(UniqueType.FoundCity).firstOrNull()
+        if (unique == null || tile.isWater || tile.isImpassible()) return null
         // Spain should still be able to build Conquistadors in a one city challenge - but can't settle them
         if (unit.civ.isOneCityChallenger() && unit.civ.hasEverOwnedOriginalCapital == true) return null
+        if (usagesLeft(unit, unique)==0) return null
 
         if (unit.currentMovement <= 0 || !tile.canBeSettled())
             return UnitAction(UnitActionType.FoundCity, action = null)
 
+        val hasActionModifiers = unique.conditionals.any { it.type?.targetTypes?.contains(UniqueTarget.UnitActionModifier) == true }
         val foundAction = {
             if (unit.civ.playerType != PlayerType.AI)
                 UncivGame.Current.settings.addCompletedTutorialTask("Found city")
@@ -191,8 +197,9 @@ object UnitActions {
             if (tile.ruleset.tileImprovements.containsKey("City center"))
                 tile.changeImprovement("City center")
             tile.removeRoad()
-            unit.destroy()
-            GUI.setUpdateWorldOnNextRender()
+
+            if (hasActionModifiers) activateSideEffects(unit, unique)
+            else unit.destroy()
         }
 
         if (unit.civ.playerType == PlayerType.AI)
@@ -200,6 +207,9 @@ object UnitActions {
 
         return UnitAction(
                 type = UnitActionType.FoundCity,
+                title =
+                    if (hasActionModifiers) actionTextWithSideEffects(UnitActionType.FoundCity.value, unique, unit)
+                    else UnitActionType.FoundCity.value,
                 uncivSound = UncivSound.Chimes,
                 action = {
                     // check if we would be breaking a promise
@@ -464,18 +474,15 @@ object UnitActions {
             val improvementName = unique.params[0]
             val improvement = tile.ruleset.tileImprovements[improvementName]
                 ?: continue
+            if (usagesLeft(unit, unique)==0) continue
 
             val resourcesAvailable = improvement.uniqueObjects.none {
                 it.isOfType(UniqueType.ConsumesResources) &&
                         (civResources[unique.params[1]] ?: 0) < unique.params[0].toInt()
             }
 
-            val sideEffectsString = getSideEffectString(unique)
-            val title = if (sideEffectsString.isEmpty()) "Create [$improvementName]"
-            else "{Create [$improvementName]} {$sideEffectsString}"
-
             finalActions += UnitAction(UnitActionType.Create,
-                title = title,
+                title = actionTextWithSideEffects("Create [$improvementName]", unique, unit),
                 action = {
                     val unitTile = unit.getTile()
                     unitTile.improvementFunctions.removeCreatesOneImprovementMarker()
@@ -483,6 +490,9 @@ object UnitActions {
                     unitTile.stopWorkingOnImprovement()
                     improvement.handleImprovementCompletion(unit)
 
+                    // without this the world screen won't the improvement because it isn't the 'last seen improvement'
+                    unit.civ.cache.updateViewableTiles()
+
                     if (unique.type == UniqueType.ConstructImprovementConsumingUnit) unit.consume()
                     else activateSideEffects(unit, unique)
                 }.takeIf {
@@ -649,9 +659,13 @@ object UnitActions {
         val triggerableTypes = setOf(UniqueTarget.Triggerable, UniqueTarget.UnitTriggerable)
         for (unique in unit.getUniques()) {
             if (unique.conditionals.none { it.type?.targetTypes?.contains(UniqueTarget.UnitActionModifier) == true }) continue
-            if (unique.type?.targetTypes?.any { it in triggerableTypes }!=true) continue
+            if (unique.type?.targetTypes?.any { it in triggerableTypes }!=true
+                    && unique.conditionals.none { it.type == UniqueType.ConditionalTimedUnique }) continue
+            if (usagesLeft(unit, unique)==0) continue
 
-            val unitAction = UnitAction(type = UnitActionType.TriggerUnique, unique.text.removeConditionals()){
+            val unitAction = UnitAction(type = UnitActionType.TriggerUnique,
+                title = actionTextWithSideEffects(unique.text.removeConditionals(), unique, unit)
+                ){
                 UniqueTriggerActivation.triggerUnitwideUnique(unique, unit)
                 activateSideEffects(unit, unique)
             }
@@ -680,21 +694,69 @@ object UnitActions {
         )
     }
 
+    fun getMovementPointsToUse(actionUnique: Unique): Int {
+        val movementCost = actionUnique.conditionals
+            .filter { it.type == UniqueType.UnitActionMovementCost }
+            .minOfOrNull { it.params[0].toInt() }
+        if (movementCost != null) return movementCost
+        return 1
+    }
+
     fun activateSideEffects(unit: MapUnit, actionUnique: Unique){
-        var conditionalsWithNoSideEffect = 0
+        val movementCost = getMovementPointsToUse(actionUnique)
+        unit.useMovementPoints(movementCost.toFloat())
+
         for (conditional in actionUnique.conditionals){
             when (conditional.type){
                 UniqueType.UnitActionConsumeUnit -> unit.consume()
-                else -> conditionalsWithNoSideEffect++
+                UniqueType.UnitActionLimitedTimes -> {
+                    if (usagesLeft(unit, actionUnique) == 1
+                            && actionUnique.conditionals.any { it.type==UniqueType.UnitActionAfterWhichConsumed }) {
+                        unit.consume()
+                        continue
+                    }
+                    val usagesSoFar = unit.abilityToTimesUsed[actionUnique.placeholderText] ?: 0
+                    unit.abilityToTimesUsed[actionUnique.placeholderText] = usagesSoFar + 1
+                }
+                else -> continue
             }
         }
-        if (conditionalsWithNoSideEffect == actionUnique.conditionals.size)
-            unit.useMovementPoints(1f)
     }
 
-    fun getSideEffectString(actionUnique: Unique): String {
+    /** Returns 'null' if usages are not limited */
+    fun usagesLeft(unit:MapUnit, actionUnique: Unique): Int?{
+        val usagesTotal = getMaxUsages(actionUnique) ?: return null
+        val usagesSoFar = unit.abilityToTimesUsed[actionUnique.placeholderText] ?: 0
+        return usagesTotal - usagesSoFar
+    }
+
+    fun getMaxUsages(actionUnique: Unique): Int? {
+        val times = actionUnique.conditionals
+            .filter { it.type == UniqueType.UnitActionLimitedTimes }
+            .maxOfOrNull { it.params[0].toInt() }
+        if (times != null) return times
+        if (actionUnique.conditionals.any { it.type == UniqueType.UnitActionOnce }) return 1
+        return null
+    }
+
+    fun actionTextWithSideEffects(originalText:String, actionUnique: Unique, unit: MapUnit): String {
+        val sideEffectString = getSideEffectString(unit, actionUnique)
+        if (sideEffectString == "") return originalText
+        else return "{$originalText} $sideEffectString"
+    }
+
+    fun getSideEffectString(unit:MapUnit, actionUnique: Unique): String {
         val effects = ArrayList<String>()
-        if (actionUnique.conditionals.any { it.type == UniqueType.UnitActionConsumeUnit }) effects += Fonts.death.toString()
+
+        val maxUsages = getMaxUsages(actionUnique)
+        if (maxUsages!=null) effects += "${usagesLeft(unit, actionUnique)}/$maxUsages"
+
+        if (actionUnique.conditionals.any { it.type == UniqueType.UnitActionConsumeUnit }
+                || actionUnique.conditionals.any { it.type == UniqueType.UnitActionAfterWhichConsumed } && usagesLeft(unit, actionUnique) == 1
+                ) effects += Fonts.death.toString()
+        else effects += getMovementPointsToUse(actionUnique).toString() + Fonts.movement
+
+
         return if (effects.isEmpty()) ""
         else "(${effects.joinToString { it.tr() }})"
     }
